bandgap — PyProcar 6.2.1 documentation

Skip to main content
`Ctrl`+`K`

# bandgap

pyprocar.scripts.bandgap(procar: str | None = None, dirname: str | None = None, outcar: str | None = None, code: str = 'vasp', fermi: float | None = None, repair: bool = True)

  A function to find the band gap

  Parameters:

    - procar (str, optional) – The PROCAR filename, by default None

    - outcar (str, optional) – The OUTCAR filename, by default None

    - code (str, optional) – The code name, by default “vasp”

    - fermi (float, optional) – The fermi energy, by default None

    - repair (bool, optional) – Boolean to repair the PROCAR file, by default True

  Returns:

    float – Returns the bandgap energy